Inverter enum

Author & Developer: Jean Bodenberg GIT: https://github.com/bodenberg/appdimens

Library: AppDimens

Orientation-based dimension swap rule applied before reading the screen axis.

Inheritance
Available extensions

Values

standard → const Inverter

EN No swap — the qualifier is used as-is. PT Sem troca — o qualificador é usado como está.

phToLw → const Inverter

EN HEIGHT in landscape becomes WIDTH (hdpLw family). PT HEIGHT em paisagem torna-se WIDTH (família hdpLw).

pwToLh → const Inverter

EN WIDTH in landscape becomes HEIGHT (wdpLh family). PT WIDTH em paisagem torna-se HEIGHT (família wdpLh).

lhToPw → const Inverter

EN HEIGHT in portrait becomes WIDTH (hdpPw family). PT HEIGHT em retrato torna-se WIDTH (família hdpPw).

lwToPh → const Inverter

EN WIDTH in portrait becomes HEIGHT (wdpPh family). PT WIDTH em retrato torna-se HEIGHT (família wdpPh).

swToLh → const Inverter

EN SMALL_WIDTH in landscape becomes HEIGHT (sdpLh family). PT SMALL_WIDTH em paisagem torna-se HEIGHT (família sdpLh).

swToLw → const Inverter

EN SMALL_WIDTH in landscape becomes WIDTH (sdpLw family). PT SMALL_WIDTH em paisagem torna-se WIDTH (família sdpLw).

swToPh → const Inverter

EN SMALL_WIDTH in portrait becomes HEIGHT (sdpPh family). PT SMALL_WIDTH em retrato torna-se HEIGHT (família sdpPh).

swToPw → const Inverter

EN SMALL_WIDTH in portrait becomes WIDTH (sdpPw family). PT SMALL_WIDTH em retrato torna-se WIDTH (família sdpPw).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Inverter>
A constant List of the values in this enum, in order of their declaration.