Inverter enum
Author & Developer: Jean Bodenberg GIT: https://github.com/bodenberg/appdimens
Library: AppDimens
Orientation-based dimension swap rule applied before reading the screen axis.
Values
- standard → const Inverter
-
EN No swap — the qualifier is used as-is. PT Sem troca — o qualificador é usado como está.
- phToLw → const Inverter
-
EN HEIGHT in landscape becomes WIDTH (
hdpLwfamily). PT HEIGHT em paisagem torna-se WIDTH (famíliahdpLw). - pwToLh → const Inverter
-
EN WIDTH in landscape becomes HEIGHT (
wdpLhfamily). PT WIDTH em paisagem torna-se HEIGHT (famíliawdpLh). - lhToPw → const Inverter
-
EN HEIGHT in portrait becomes WIDTH (
hdpPwfamily). PT HEIGHT em retrato torna-se WIDTH (famíliahdpPw). - lwToPh → const Inverter
-
EN WIDTH in portrait becomes HEIGHT (
wdpPhfamily). PT WIDTH em retrato torna-se HEIGHT (famíliawdpPh). - swToLh → const Inverter
-
EN SMALL_WIDTH in landscape becomes HEIGHT (
sdpLhfamily). PT SMALL_WIDTH em paisagem torna-se HEIGHT (famíliasdpLh). - swToLw → const Inverter
-
EN SMALL_WIDTH in landscape becomes WIDTH (
sdpLwfamily). PT SMALL_WIDTH em paisagem torna-se WIDTH (famíliasdpLw). - swToPh → const Inverter
-
EN SMALL_WIDTH in portrait becomes HEIGHT (
sdpPhfamily). PT SMALL_WIDTH em retrato torna-se HEIGHT (famíliasdpPh). - swToPw → const Inverter
-
EN SMALL_WIDTH in portrait becomes WIDTH (
sdpPwfamily). PT SMALL_WIDTH em retrato torna-se WIDTH (famíliasdpPw).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited